'use client';
import React, { useCallback } from 'react';
import { CodeEditor } from '../../../elements/CodeEditor/index.js';
import LabelComp from '../../Label/index.js';
import useField from '../../useField/index.js';
import { withCondition } from '../../withCondition/index.js';
import { fieldBaseClass } from '../shared.js';
const prismToMonacoLanguageMap = {
    js: 'javascript',
    ts: 'typescript'
};
const baseClass = 'code-field';
const Code = (props)=>{
    const { name, AfterInput, BeforeInput, Description, Error, Label: LabelFromProps, className, label, path: pathFromProps, readOnly, required, style, validate, width } = props;
    const Label = LabelFromProps || /*#__PURE__*/ React.createElement(LabelComp, {
        label: label,
        required: required
    });
    const editorOptions = 'editorOptions' in props ? props.editorOptions : {};
    const language = 'language' in props ? props.language : 'javascript';
    const memoizedValidate = useCallback((value, options)=>{
        if (typeof validate === 'function') {
            return validate(value, {
                ...options,
                required
            });
        }
    }, [
        validate,
        required
    ]);
    const { path, setValue, showError, value } = useField({
        path: pathFromProps || name,
        validate: memoizedValidate
    });
    return /*#__PURE__*/ React.createElement("div", {
        className: [
            fieldBaseClass,
            baseClass,
            className,
            showError && 'error',
            readOnly && 'read-only'
        ].filter(Boolean).join(' '),
        style: {
            ...style,
            width
        }
    }, Error, Label, /*#__PURE__*/ React.createElement("div", null, BeforeInput, /*#__PURE__*/ React.createElement(CodeEditor, {
        defaultLanguage: prismToMonacoLanguageMap[language] || language,
        onChange: readOnly ? ()=>null : (val)=>setValue(val),
        options: editorOptions,
        readOnly: readOnly,
        value: value || ''
    }), AfterInput), Description);
};
export default withCondition(Code);

//# sourceMappingURL=index.js.map